Entitlements are used to grant privileges to applications, like enabling Apple Pay, Push notifications, debugging privileges, running unsigned code, etc.

Reviewing this list to identify the application capabilities and attack surface.